package Bundle::Locale::CLDR::Eurozone;

use version;

our $VERSION = version->declare('v0.44.0');

=head1 NAME

Bundle::Locale::CLDR::Eurozone

=head1 CONTENTS

Locale::CLDR::Locales::An 0.44.0

Locale::CLDR::Locales::Br 0.44.0

Locale::CLDR::Locales::Ca 0.44.0

Locale::CLDR::Locales::Co 0.44.0

Locale::CLDR::Locales::De 0.44.0

Locale::CLDR::Locales::El 0.44.0

Locale::CLDR::Locales::Es 0.44.0

Locale::CLDR::Locales::Et 0.44.0

Locale::CLDR::Locales::Eu 0.44.0

Locale::CLDR::Locales::Fi 0.44.0

Locale::CLDR::Locales::Fr 0.44.0

Locale::CLDR::Locales::Fy 0.44.0

Locale::CLDR::Locales::Ga 0.44.0

Locale::CLDR::Locales::Gl 0.44.0

Locale::CLDR::Locales::Ie 0.44.0

Locale::CLDR::Locales::It 0.44.0

Locale::CLDR::Locales::Lb 0.44.0

Locale::CLDR::Locales::Lt 0.44.0

Locale::CLDR::Locales::Lv 0.44.0

Locale::CLDR::Locales::Mt 0.44.0

Locale::CLDR::Locales::Nl 0.44.0

Locale::CLDR::Locales::Oc 0.44.0

Locale::CLDR::Locales::Pt 0.44.0

Locale::CLDR::Locales::Sc 0.44.0

Locale::CLDR::Locales::Se 0.44.0

Locale::CLDR::Locales::Sk 0.44.0

Locale::CLDR::Locales::Sl 0.44.0

Locale::CLDR::Locales::Sv 0.44.0

Locale::CLDR::Locales::Tr 0.44.0

Locale::CLDR::Locales::Wa 0.44.0

Locale::CLDR::Locales::Ast 0.44.0

Locale::CLDR::Locales::Dsb 0.44.0

Locale::CLDR::Locales::Frr 0.44.0

Locale::CLDR::Locales::Fur 0.44.0

Locale::CLDR::Locales::Gsw 0.44.0

Locale::CLDR::Locales::Hsb 0.44.0

Locale::CLDR::Locales::Ksh 0.44.0

Locale::CLDR::Locales::Lij 0.44.0

Locale::CLDR::Locales::Lmo 0.44.0

Locale::CLDR::Locales::Nds 0.44.0

Locale::CLDR::Locales::Scn 0.44.0

Locale::CLDR::Locales::Smn 0.44.0

Locale::CLDR::Locales::Sms 0.44.0

Locale::CLDR::Locales::Vec 0.44.0

Locale::CLDR::Locales::An::Latn 0.44.0

Locale::CLDR::Locales::Br::Latn 0.44.0

Locale::CLDR::Locales::Ca::Latn 0.44.0

Locale::CLDR::Locales::Co::Latn 0.44.0

Locale::CLDR::Locales::De::Latn 0.44.0

Locale::CLDR::Locales::El::Grek 0.44.0

Locale::CLDR::Locales::Es::Latn 0.44.0

Locale::CLDR::Locales::Et::Latn 0.44.0

Locale::CLDR::Locales::Eu::Latn 0.44.0

Locale::CLDR::Locales::Fi::Latn 0.44.0

Locale::CLDR::Locales::Fr::Latn 0.44.0

Locale::CLDR::Locales::Fy::Latn 0.44.0

Locale::CLDR::Locales::Ga::Latn 0.44.0

Locale::CLDR::Locales::Gl::Latn 0.44.0

Locale::CLDR::Locales::Ie::Latn 0.44.0

Locale::CLDR::Locales::It::Latn 0.44.0

Locale::CLDR::Locales::Lb::Latn 0.44.0

Locale::CLDR::Locales::Lt::Latn 0.44.0

Locale::CLDR::Locales::Lv::Latn 0.44.0

Locale::CLDR::Locales::Mt::Latn 0.44.0

Locale::CLDR::Locales::Nl::Latn 0.44.0

Locale::CLDR::Locales::Oc::Latn 0.44.0

Locale::CLDR::Locales::Pt::Latn 0.44.0

Locale::CLDR::Locales::Sc::Latn 0.44.0

Locale::CLDR::Locales::Se::Latn 0.44.0

Locale::CLDR::Locales::Sk::Latn 0.44.0

Locale::CLDR::Locales::Sl::Latn 0.44.0

Locale::CLDR::Locales::Sv::Latn 0.44.0

Locale::CLDR::Locales::Tr::Latn 0.44.0

Locale::CLDR::Locales::Wa::Latn 0.44.0

Locale::CLDR::Locales::Ast::Latn 0.44.0

Locale::CLDR::Locales::Dsb::Latn 0.44.0

Locale::CLDR::Locales::Frr::Latn 0.44.0

Locale::CLDR::Locales::Fur::Latn 0.44.0

Locale::CLDR::Locales::Gsw::Latn 0.44.0

Locale::CLDR::Locales::Hsb::Latn 0.44.0

Locale::CLDR::Locales::Ksh::Latn 0.44.0

Locale::CLDR::Locales::Lij::Latn 0.44.0

Locale::CLDR::Locales::Lmo::Latn 0.44.0

Locale::CLDR::Locales::Nds::Latn 0.44.0

Locale::CLDR::Locales::Scn::Latn 0.44.0

Locale::CLDR::Locales::Smn::Latn 0.44.0

Locale::CLDR::Locales::Sms::Latn 0.44.0

Locale::CLDR::Locales::Vec::Latn 0.44.0

Locale::CLDR::Locales::An::Latn::Es 0.44.0

Locale::CLDR::Locales::Br::Latn::Fr 0.44.0

Locale::CLDR::Locales::Ca::Latn::Es 0.44.0

Locale::CLDR::Locales::Ca::Latn::Fr 0.44.0

Locale::CLDR::Locales::Ca::Latn::It 0.44.0

Locale::CLDR::Locales::Co::Latn::Fr 0.44.0

Locale::CLDR::Locales::De::Latn::At 0.44.0

Locale::CLDR::Locales::De::Latn::Be 0.44.0

Locale::CLDR::Locales::De::Latn::De 0.44.0

Locale::CLDR::Locales::De::Latn::It 0.44.0

Locale::CLDR::Locales::De::Latn::Lu 0.44.0

Locale::CLDR::Locales::El::Grek::Cy 0.44.0

Locale::CLDR::Locales::El::Grek::Gr 0.44.0

Locale::CLDR::Locales::En::Latn::At 0.44.0

Locale::CLDR::Locales::En::Latn::Be 0.44.0

Locale::CLDR::Locales::En::Latn::Cy 0.44.0

Locale::CLDR::Locales::En::Latn::De 0.44.0

Locale::CLDR::Locales::En::Latn::Fi 0.44.0

Locale::CLDR::Locales::En::Latn::Ie 0.44.0

Locale::CLDR::Locales::En::Latn::Mt 0.44.0

Locale::CLDR::Locales::En::Latn::Nl 0.44.0

Locale::CLDR::Locales::En::Latn::Si 0.44.0

Locale::CLDR::Locales::Es::Latn::Es 0.44.0

Locale::CLDR::Locales::Et::Latn::Ee 0.44.0

Locale::CLDR::Locales::Eu::Latn::Es 0.44.0

Locale::CLDR::Locales::Fi::Latn::Fi 0.44.0

Locale::CLDR::Locales::Fr::Latn::Be 0.44.0

Locale::CLDR::Locales::Fr::Latn::Fr 0.44.0

Locale::CLDR::Locales::Fr::Latn::Lu 0.44.0

Locale::CLDR::Locales::Fy::Latn::Nl 0.44.0

Locale::CLDR::Locales::Ga::Latn::Ie 0.44.0

Locale::CLDR::Locales::Gl::Latn::Es 0.44.0

Locale::CLDR::Locales::Ie::Latn::Ee 0.44.0

Locale::CLDR::Locales::It::Latn::It 0.44.0

Locale::CLDR::Locales::Lb::Latn::Lu 0.44.0

Locale::CLDR::Locales::Lt::Latn::Lt 0.44.0

Locale::CLDR::Locales::Lv::Latn::Lv 0.44.0

Locale::CLDR::Locales::Mt::Latn::Mt 0.44.0

Locale::CLDR::Locales::Nl::Latn::Be 0.44.0

Locale::CLDR::Locales::Nl::Latn::Nl 0.44.0

Locale::CLDR::Locales::Oc::Latn::Es 0.44.0

Locale::CLDR::Locales::Oc::Latn::Fr 0.44.0

Locale::CLDR::Locales::Pt::Latn::Lu 0.44.0

Locale::CLDR::Locales::Pt::Latn::Pt 0.44.0

Locale::CLDR::Locales::Sc::Latn::It 0.44.0

Locale::CLDR::Locales::Se::Latn::Fi 0.44.0

Locale::CLDR::Locales::Sk::Latn::Sk 0.44.0

Locale::CLDR::Locales::Sl::Latn::Si 0.44.0

Locale::CLDR::Locales::Sv::Latn::Fi 0.44.0

Locale::CLDR::Locales::Tr::Latn::Cy 0.44.0

Locale::CLDR::Locales::Wa::Latn::Be 0.44.0

Locale::CLDR::Locales::Ast::Latn::Es 0.44.0

Locale::CLDR::Locales::Dsb::Latn::De 0.44.0

Locale::CLDR::Locales::En::Latn::001 0.44.0

Locale::CLDR::Locales::En::Latn::150 0.44.0

Locale::CLDR::Locales::Frr::Latn::De 0.44.0

Locale::CLDR::Locales::Fur::Latn::It 0.44.0

Locale::CLDR::Locales::Gsw::Latn::Fr 0.44.0

Locale::CLDR::Locales::Hsb::Latn::De 0.44.0

Locale::CLDR::Locales::Ksh::Latn::De 0.44.0

Locale::CLDR::Locales::Lij::Latn::It 0.44.0

Locale::CLDR::Locales::Lmo::Latn::It 0.44.0

Locale::CLDR::Locales::Nds::Latn::De 0.44.0

Locale::CLDR::Locales::Nds::Latn::Nl 0.44.0

Locale::CLDR::Locales::Scn::Latn::It 0.44.0

Locale::CLDR::Locales::Smn::Latn::Fi 0.44.0

Locale::CLDR::Locales::Sms::Latn::Fi 0.44.0

Locale::CLDR::Locales::Vec::Latn::It 0.44.0


=cut

1;

